@@ -23,7 +23,7 @@ from aliyunsdkdyplsapi.endpoint import endpoint_data
 class BindAxnExtensionRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'BindAxnExtension','dypls')
+		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'BindAxnExtension')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -131,4 +131,10 @@ class BindAxnExtensionRequest(RpcRequest):
 		return self.get_query_params().get('ASRModelId')
 
 	def set_ASRModelId(self,ASRModelId):
-		self.add_query_param('ASRModelId',ASRModelId)
\ No newline at end of file
+		self.add_query_param('ASRModelId',ASRModelId)
+
+	def get_CallRestrict(self):
+		return self.get_query_params().get('CallRestrict')
+
+	def set_CallRestrict(self,CallRestrict):
+		self.add_query_param('CallRestrict',CallRestrict)
\ No newline at end of file
