@@ -23,7 +23,7 @@ from aliyunsdkdyplsapi.endpoint import endpoint_data
 class BindAxnRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'BindAxn','dypls')
+		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'BindAxn')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -43,6 +43,12 @@ class BindAxnRequest(RpcRequest):
 	def set_CallDisplayType(self,CallDisplayType):
 		self.add_query_param('CallDisplayType',CallDisplayType)
 
+	def get_CallTimeout(self):
+		return self.get_query_params().get('CallTimeout')
+
+	def set_CallTimeout(self,CallTimeout):
+		self.add_query_param('CallTimeout',CallTimeout)
+
 	def get_PhoneNoX(self):
 		return self.get_query_params().get('PhoneNoX')
 
@@ -131,4 +137,10 @@ class BindAxnRequest(RpcRequest):
 		return self.get_query_params().get('ASRModelId')
 
 	def set_ASRModelId(self,ASRModelId):
-		self.add_query_param('ASRModelId',ASRModelId)
\ No newline at end of file
+		self.add_query_param('ASRModelId',ASRModelId)
+
+	def get_CallRestrict(self):
+		return self.get_query_params().get('CallRestrict')
+
+	def set_CallRestrict(self,CallRestrict):
+		self.add_query_param('CallRestrict',CallRestrict)
\ No newline at end of file
