@@ -23,7 +23,7 @@ from aliyunsdkdyplsapi.endpoint import endpoint_data
 class QueryPhoneNoAByTrackNoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'QueryPhoneNoAByTrackNo','dypls')
+		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'QueryPhoneNoAByTrackNo')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -37,6 +37,18 @@ class QueryPhoneNoAByTrackNoRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
+	def get_CabinetNo(self):
+		return self.get_query_params().get('CabinetNo')
+
+	def set_CabinetNo(self,CabinetNo):
+		self.add_query_param('CabinetNo',CabinetNo)
+
+	def get_PhoneNoX(self):
+		return self.get_query_params().get('PhoneNoX')
+
+	def set_PhoneNoX(self,PhoneNoX):
+		self.add_query_param('PhoneNoX',PhoneNoX)
+
 	def get_ResourceOwnerAccount(self):
 		return self.get_query_params().get('ResourceOwnerAccount')
 
@@ -53,10 +65,4 @@ class QueryPhoneNoAByTrackNoRequest(RpcRequest):
 		return self.get_query_params().get('trackNo')
 
 	def set_trackNo(self,trackNo):
-		self.add_query_param('trackNo',trackNo)
-
-	def get_PhoneNoX(self):
-		return self.get_query_params().get('PhoneNoX')
-
-	def set_PhoneNoX(self,PhoneNoX):
-		self.add_query_param('PhoneNoX',PhoneNoX)
\ No newline at end of file
+		self.add_query_param('trackNo',trackNo)
\ No newline at end of file
