@@ -23,7 +23,7 @@ from aliyunsdkdyplsapi.endpoint import endpoint_data
 class QuerySecretNoRemainRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'QuerySecretNoRemain','dypls')
+		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'QuerySecretNoRemain')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
